print("import: 'pandas_ml'")
import pandas_ml

print("import: 'pandas_ml.confusion_matrix'")
import pandas_ml.confusion_matrix

print("import: 'pandas_ml.confusion_matrix.test'")
import pandas_ml.confusion_matrix.test

print("import: 'pandas_ml.core'")
import pandas_ml.core

print("import: 'pandas_ml.imbaccessors'")
import pandas_ml.imbaccessors

print("import: 'pandas_ml.imbaccessors.test'")
import pandas_ml.imbaccessors.test

print("import: 'pandas_ml.misc'")
import pandas_ml.misc

print("import: 'pandas_ml.misc.test'")
import pandas_ml.misc.test

print("import: 'pandas_ml.skaccessors'")
import pandas_ml.skaccessors

print("import: 'pandas_ml.skaccessors.test'")
import pandas_ml.skaccessors.test

print("import: 'pandas_ml.smaccessors'")
import pandas_ml.smaccessors

print("import: 'pandas_ml.smaccessors.test'")
import pandas_ml.smaccessors.test

print("import: 'pandas_ml.snsaccessors'")
import pandas_ml.snsaccessors

print("import: 'pandas_ml.snsaccessors.test'")
import pandas_ml.snsaccessors.test

print("import: 'pandas_ml.test'")
import pandas_ml.test

print("import: 'pandas_ml.util'")
import pandas_ml.util

print("import: 'pandas_ml.xgboost'")
import pandas_ml.xgboost

print("import: 'pandas_ml.xgboost.test'")
import pandas_ml.xgboost.test

